define(["dojo/_base/declare",
        "dojo/_base/lang",
        "dijit/_Widget",        
        "dijit/_TemplatedMixin",
        "dijit/_WidgetsInTemplateMixin",
        "dojo/text!./templates/ResultWizardPage.html",
        "dojo/string",
        "dojo/dom-style",
        "dojo/store/Memory",
        "dojo/data/ObjectStore",
        "dojo/request/xhr",
        "admin/users/dialogs/WizardPage",
        "dojo/i18n!../nls/user_resources",
        "dijit/form/RadioButton",
        "dojox/form/Uploader",
        "dojox/form/uploader/plugins/IFrame",
        "idx/form/TextBox",
        "idx/form/RadioButtonSet",
        "dojo/data/ItemFileWriteStore", 
        "dojox/grid/EnhancedGrid"
        ],
        function(dDeclare,
                dLang,
                dWidget,
                dTemplatedMixin,
                dWidgetsInTemplateMixin,
                templateText,
                dString,
                domStyle,
                Memory,
                ObjectStore,
                xhr,
                WizardPage,
                resources) {
return dDeclare("admin.users.dialogs.ResultWizardPage", [dWidget,dTemplatedMixin,dWidgetsInTemplateMixin,WizardPage], {

    /**
     * @private
     */
    baseClass: "ResultWizardPage",

    /**
     * The path to the widget template for the dijit._TemplatedMixin base class.
     * 
     * @private
     * @constant
     * @type String
     */
    templateString: templateText,
    
    /** 
     * Indicate if this widget is also a container
     * @private
     */
    isContainer: false,
    
    /**
     * Indicate if there are widgets in the template
     */
    widgetsInTemplate: true,
    
    pageDescription: resources["resultDescription"],
    
    ldapNoUsersFoundMessage: resources['ldapNoUsersFoundMessage'],
    
    ldapRetrievalError: resources['ldapRetrievalError'],
    
    ldapPortOutofRange: resources['ldapPortOutofRange'],
    
    ldapUnknowHost: resources['ldapUnknowHost'],
    
    ldapConnectionError: resources['ldapConnectionError'],
    
    retrieveUsersMessage: resources['retrievingUserMessage'],
    
    ldapError: false,
    
	/**
	 * Get the title of this page
	 */
	getTitle:function() {
		return "Select Import Source";
	},
	
	/**
	 * Get the description of this page
	 */
	getDescription:function() {
		return this.pageDescription;
	},
	
	/**
	 * Check if this page is complete
	 */
	isComplete:function() {
		if (this.controller.getExternalUserList() != null) {
			return true;
		}
		return !this.ldapError;
	},

	/**
	 * The startup function
	 */
	startup:function() {
		this.inherited(arguments);
		
	},
	
	/**
	 * Retrieve users
	 */
	retrieveUsers:function() {
		if (this.controller != null) {
			var data = this.controller.getExternalUserList();
			if (data != null) {
				console.log("setting userGrid.store:", data);
				var store = new ObjectStore({objectStore:new Memory({ data: data})});
				this.userGrid.setStore(store)
				this.userGrid.render();
			}
			else {
				var store = new ObjectStore({objectStore:new Memory({data: []})});
				this.userGrid.setStore(store)
				this.userGrid.render();
				var ldapInfo = this.controller.getLDAPInfo();
				var ldapFilters = this.controller.getLDAPFilters();
				dLang.mixin(ldapInfo, ldapFilters);
				var message = this.retrieveUsersMessage;
				this._setGridMessage(message);
				xhr.post("/optim/rest/security/registry/ldapload", 
			        {
			        	handleAs: "json",
			        	data: JSON.stringify(ldapInfo),
			        }).then(dLang.hitch(this, "_retrieveFromLDAPComplete"), dLang.hitch(this, "_retrieveFromLDAPFailed"), function(evt){
			        	//do nothing
			        	console.log(evt);
			        });
			}
		}
		
	},
	
	/**
	 * Retrieve user from LDAP complete
	 */
	_retrieveFromLDAPComplete:function(data) {
		console.log(data);
		this.ldapError = false;
		if (typeof data.items != "undefined" && data.items.length == 0) {
			this._setGridMessage(this.ldapNoUsersFoundMessage);
		}
		else if (typeof data.message != "undefined") {
			console.log(data.message);
			if (data.code == "1003") {//port out of range
				this._setGridErrorMessage(this.ldapPortOutofRange);
			}
			else if (data.code == "1002") {//unknown host
				this._setGridErrorMessage(this.ldapUnknowHost);
			}
			else if (data.code == "1001") {
				this._setGridErrorMessage(dLang.replace(this.ldapConnectionError, {"errorMessage": data.message}));
			}
			else {
				this._setGridErrorMessage(dLang.replace(this.ldapRetrievalError, {"errorMessage": data.message}));
			}
			this.ldapError=true;
		}
		else {
			var store = new ObjectStore({objectStore:new Memory({ data: data})});
			this.userGrid.setStore(store)
			this.userGrid.render();
		}
		this.controller.updateWizardButtonStates();
	},
	
	/**
	 * Retrieve user from LDAP failed
	 */
	_retrieveFromLDAPFailed:function(error) {
		console.log(error);
		console.log(error.status);
		this._setGridErrorMessage(error);
		this.controller.updateWizardButtonStates();
	},
	
	/**
	 * Set grid message
	 */
	_setGridMessage:function(message) {
		this.userGrid.showMessage("<div class='oneuiMsgInfo16' style='padding-left:10px;width:100%;'>" + message + "</div>");
	},
	
	/**
	 * Set grid error message
	 */
	_setGridErrorMessage:function(message) {
		console.log("showError message:" + message);
		this.userGrid.showMessage("<div class='errorIcon16' style='padding-left:10px;width:100%;'>" + message + "</div>");
	},
	
	/**
	 * Page is displayed - populate user grid
	 */
    pageDisplayed:function() {
    	console.log("pageDisplayed");
		if (this.userGrid == null) {
			var layout = [[
		               {'name':'Logon ID', 'field':'userId', width:'15%'},
		               {'name':'Name', 'field':'userName', width:"30%"},
		               {'name':'Email', 'field':'userEmail', width: "55%"},
		               ]];
			this.userGrid = new dojox.grid.EnhancedGrid({
				store: null,
				structure: layout,
				autoHeight:true,
				keepSelection:true, 
				style: "width:99%; height:95%;",
				loadingMessage:'loading...'
			}, document.createElement('div'));
			this.centerPane.domNode.appendChild(this.userGrid.domNode);
			this.userGrid.startup();
		}
		this.retrieveUsers();
	}
});
});
